@@ -7,6 +7,8 @@ STEM=$1
 
 cd $AUTOPKGTEST_TMP
 cp $AUTOPKGTEST_SRC/debian/tests/{$STEM.cpp,Makefile} .
-make $STEM
+
+# Avoid test failures due to compiler warnings.
+make $STEM 2>&1
 
 ./$STEM
